@@ -19,7 +19,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/golang/glog"
 	configv1 "github.com/openshift/api/config/v1"
 	"github.com/pkg/errors"
 	"github.com/prometheus/client_golang/prometheus"
@@ -29,6 +28,7 @@ import (
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/util/workqueue"
+	"k8s.io/klog"
 
 	"github.com/openshift/cluster-monitoring-operator/pkg/client"
 	"github.com/openshift/cluster-monitoring-operator/pkg/manifests"
@@ -39,10 +39,12 @@ const (
 	resyncPeriod = 5 * time.Minute
 
 	// see https://github.com/kubernetes/apiserver/blob/b571c70e6e823fd78910c3f5b9be895a756f4cbb/pkg/server/options/authentication.go#L239
-	apiAuthenticationConfigMap = "kube-system/extension-apiserver-authentication"
-	kubeletServingCAConfigMap  = "openshift-config-managed/kubelet-serving-ca"
-	prometheusAdapterTLSSecret = "openshift-monitoring/prometheus-adapter-tls"
-	etcdClientCAConfigMap      = "openshift-config/etcd-metrics-serving-ca"
+	apiAuthenticationConfigMap    = "kube-system/extension-apiserver-authentication"
+	kubeletServingCAConfigMap     = "openshift-config-managed/kubelet-serving-ca"
+	prometheusAdapterTLSSecret    = "openshift-monitoring/prometheus-adapter-tls"
+	etcdClientCAConfigMap         = "openshift-config/etcd-metrics-serving-ca"
+	telemeterCABundleConfigMap    = "openshift-monitoring/telemeter-trusted-ca-bundle"
+	alertmanagerCABundleConfigMap = "openshift-monitoring/alertmanager-trusted-ca-bundle"
 )
 
 type Operator struct {
@@ -153,7 +155,7 @@ func (o *Operator) Run(stopc <-chan struct{}) error {
 			errChan <- errors.Wrap(err, "communicating with server failed")
 			return
 		}
-		glog.V(4).Infof("Connection established (cluster-version: %s)", v)
+		klog.V(4).Infof("Connection established (cluster-version: %s)", v)
 
 		errChan <- nil
 	}()
@@ -170,12 +172,12 @@ func (o *Operator) Run(stopc <-chan struct{}) error {
 	go o.cmapInf.Run(stopc)
 	go o.kubeSystemCmapInf.Run(stopc)
 
-	glog.V(4).Info("Waiting for initial cache sync.")
+	klog.V(4).Info("Waiting for initial cache sync.")
 	ok := cache.WaitForCacheSync(stopc, o.cmapInf.HasSynced, o.kubeSystemCmapInf.HasSynced)
 	if !ok {
 		return errors.New("failed to sync informers")
 	}
-	glog.V(4).Info("Initial cache sync done.")
+	klog.V(4).Info("Initial cache sync done.")
 
 	go o.worker()
 
@@ -185,7 +187,7 @@ func (o *Operator) Run(stopc <-chan struct{}) error {
 	key := o.namespace + "/" + o.configMapName
 	_, exists, _ := o.cmapInf.GetStore().GetByKey(key)
 	if !exists {
-		glog.Info("ConfigMap to configure stack does not exist. Reconciling with default config every 5 minutes.")
+		klog.Info("ConfigMap to configure stack does not exist. Reconciling with default config every 5 minutes.")
 		o.enqueue(key)
 	}
 
@@ -196,7 +198,7 @@ func (o *Operator) Run(stopc <-chan struct{}) error {
 		case <-ticker.C:
 			_, exists, _ := o.cmapInf.GetStore().GetByKey(key)
 			if !exists {
-				glog.Info("ConfigMap to configure stack does not exist. Reconciling with default config every 5 minutes.")
+				klog.Info("ConfigMap to configure stack does not exist. Reconciling with default config every 5 minutes.")
 				o.enqueue(key)
 			}
 		}
@@ -208,7 +210,7 @@ func (o *Operator) Run(stopc <-chan struct{}) error {
 func (o *Operator) keyFunc(obj interface{}) (string, bool) {
 	k, err := cache.DeletionHandlingMetaNamespaceKeyFunc(obj)
 	if err != nil {
-		glog.Errorf("creating key failed, err: %s", err)
+		klog.Errorf("creating key failed, err: %s", err)
 		return k, false
 	}
 	return k, true
@@ -220,7 +222,7 @@ func (o *Operator) handleEvent(obj interface{}) {
 		return
 	}
 
-	glog.V(5).Infof("ConfigMap updated: %s", key)
+	klog.V(5).Infof("ConfigMap or Secret updated: %s", key)
 
 	cmoConfigMap := o.namespace + "/" + o.configMapName
 
@@ -230,8 +232,10 @@ func (o *Operator) handleEvent(obj interface{}) {
 	case kubeletServingCAConfigMap:
 	case prometheusAdapterTLSSecret:
 	case etcdClientCAConfigMap:
+	case telemeterCABundleConfigMap:
+	case alertmanagerCABundleConfigMap:
 	default:
-		glog.V(5).Infof("ConfigMap (%s) not triggering an update.", key)
+		klog.V(5).Infof("ConfigMap or Secret (%s) not triggering an update.", key)
 		return
 	}
 
@@ -260,7 +264,7 @@ func (o *Operator) processNextWorkItem() bool {
 	}
 
 	o.reconcileErrors.Inc()
-	glog.Errorf("Syncing %q failed", key)
+	klog.Errorf("Syncing %q failed", key)
 	utilruntime.HandleError(errors.Wrap(err, fmt.Sprintf("sync %q failed", key)))
 	o.queue.AddRateLimited(key)
 
@@ -299,33 +303,34 @@ func (o *Operator) sync(key string) error {
 			tasks.NewTaskSpec("Updating Alertmanager", tasks.NewAlertmanagerTask(o.client, factory)),
 			tasks.NewTaskSpec("Updating node-exporter", tasks.NewNodeExporterTask(o.client, factory)),
 			tasks.NewTaskSpec("Updating kube-state-metrics", tasks.NewKubeStateMetricsTask(o.client, factory)),
+			tasks.NewTaskSpec("Updating openshift-state-metrics", tasks.NewOpenShiftStateMetricsTask(o.client, factory)),
 			tasks.NewTaskSpec("Updating prometheus-adapter", tasks.NewPrometheusAdapterTaks(o.namespace, o.client, factory)),
 			tasks.NewTaskSpec("Updating Telemeter client", tasks.NewTelemeterClientTask(o.client, factory, config.TelemeterClientConfig)),
 			tasks.NewTaskSpec("Updating configuration sharing", tasks.NewConfigSharingTask(o.client, factory)),
 		},
 	)
 
-	glog.Info("Updating ClusterOperator status to in progress.")
+	klog.Info("Updating ClusterOperator status to in progress.")
 	err := o.client.StatusReporter().SetInProgress()
 	if err != nil {
-		glog.Errorf("error occurred while setting status to in progress: %v", err)
+		klog.Errorf("error occurred while setting status to in progress: %v", err)
 	}
 
 	taskName, err := tl.RunAll()
 	if err != nil {
-		glog.Infof("Updating ClusterOperator status to failed. Err: %v", err)
+		klog.Infof("Updating ClusterOperator status to failed. Err: %v", err)
 		failedTaskReason := strings.Join(strings.Fields(taskName+"Failed"), "")
 		reportErr := o.client.StatusReporter().SetFailed(err, failedTaskReason)
 		if reportErr != nil {
-			glog.Errorf("error occurred while setting status to failed: %v", reportErr)
+			klog.Errorf("error occurred while setting status to failed: %v", reportErr)
 		}
 		return err
 	}
 
-	glog.Info("Updating ClusterOperator status to done.")
+	klog.Info("Updating ClusterOperator status to done.")
 	err = o.client.StatusReporter().SetDone()
 	if err != nil {
-		glog.Errorf("error occurred while setting status to done: %v", err)
+		klog.Errorf("error occurred while setting status to done: %v", err)
 	}
 
 	return nil
@@ -336,12 +341,12 @@ func (o *Operator) loadConfig(key string) *manifests.Config {
 
 	obj, found, err := o.cmapInf.GetStore().GetByKey(key)
 	if err != nil {
-		glog.Warningf("An error occurred retrieving the Cluster Monitoring ConfigMap. Using defaults: %v", err)
+		klog.Warningf("An error occurred retrieving the Cluster Monitoring ConfigMap. Using defaults: %v", err)
 		return c
 	}
 
 	if !found {
-		glog.Warning("No Cluster Monitoring ConfigMap was found. Using defaults.")
+		klog.Warning("No Cluster Monitoring ConfigMap was found. Using defaults.")
 		return c
 	}
 
@@ -349,13 +354,13 @@ func (o *Operator) loadConfig(key string) *manifests.Config {
 	configContent, found := cmap.Data["config.yaml"]
 
 	if !found {
-		glog.Warning("Cluster Monitoring ConfigMap does not contain a config. Using defaults.")
+		klog.Warning("Cluster Monitoring ConfigMap does not contain a config. Using defaults.")
 		return c
 	}
 
 	cParsed, err := manifests.NewConfigFromString(configContent)
 	if err != nil {
-		glog.Warningf("Cluster Monitoring config could not be parsed. Using defaults: %v", err)
+		klog.Warningf("Cluster Monitoring config could not be parsed. Using defaults: %v", err)
 		return c
 	}
 
@@ -372,7 +377,7 @@ func (o *Operator) Config(key string) *manifests.Config {
 		})
 
 		if err != nil {
-			glog.Warningf("Could not fetch cluster version from API. Proceeding without it: %v", err)
+			klog.Warningf("Could not fetch cluster version from API. Proceeding without it: %v", err)
 		}
 
 		err = c.LoadToken(func() (*v1.Secret, error) {
@@ -380,26 +385,25 @@ func (o *Operator) Config(key string) *manifests.Config {
 		})
 
 		if err != nil {
-			glog.Warningf("Error loading token from API. Proceeding without it: %v", err)
+			klog.Warningf("Error loading token from API. Proceeding without it: %v", err)
 		}
 	}
 
 	err := c.LoadProxy(func() (*configv1.Proxy, error) {
 		return o.client.GetProxy("cluster")
 	})
-
 	if err != nil {
-		glog.Warningf("Could not load proxy configuration from API. This is expected and message can be ignored when proxy configuration doesn't exist. Proceeding without it: %v", err)
+		klog.Warningf("Could not load proxy configuration from API. This is expected and message can be ignored when proxy configuration doesn't exist. Proceeding without it: %v", err)
 	}
 
 	cm, err := o.client.GetConfigmap("openshift-config", "etcd-metric-serving-ca")
 	if err != nil {
-		glog.Warningf("Error loading etcd CA certificates for Prometheus. Proceeding with etcd disabled. Error: %v", err)
+		klog.Warningf("Error loading etcd CA certificates for Prometheus. Proceeding with etcd disabled. Error: %v", err)
 	}
 
 	s, err := o.client.GetSecret("openshift-config", "etcd-metric-client")
 	if err != nil {
-		glog.Warningf("Error loading etcd client secrets for Prometheus. Proceeding with etcd disabled. Error: %v", err)
+		klog.Warningf("Error loading etcd client secrets for Prometheus. Proceeding with etcd disabled. Error: %v", err)
 	}
 
 	if err == nil {
